HiLearn
=======

A small library of machine learning methods. As most of them are often used (by myself), they are standardized and collected here.


What's inside?
---------------

* a wrap of cross-validation for regression and classification models.

* a mixture of linear regression model

* a plot function to show correlation between a pair of data (for regression)

* a plot function to show ROC curve with AUC score (for classification)

* a few plot functions, e.g., set colors, group boxplots, venn3 plots.


How to install?
---------------

Download the codes from this github repository and then run the following command line:

::

    python setup.py install

If you don't have the root permission, add ``--user``.


Tutorial and Gallery
--------------------

See the tutorial_ for how to use, e.g., `cross-validation functions and plots`_ and `hilearn plot`_.


.. _tutorial: https://github.com/huangyh09/hilearn/tree/master/tutorial

.. _`cross-validation functions and plots`: https://github.com/huangyh09/hilearn/blob/master/tutorial/tutorial_cross-validation.rst

.. _`hilearn plot`: https://github.com/huangyh09/hilearn/blob/master/tutorial/tutorial_plots.rst
